==> statistic-2.0.zip: index.php <==
<?
include('stat_functions.php');
include('db.php');
DB_Init('localhost', 'root', '', 'statistic');
DB_Query('SET CHARACTER SET latin2');

$Debug = 1;

function EditTime($Time)
{
      global $Months;
      
      $Output = '<form style="display: inline;" action="?Operation=SetTime&Time='.$Time.'" method="post">';
      
      $TimeParts = getdate($_SESSION[$Time]);
      //print_r($TimeParts); 
          
      // Day selection
      $Output .= '<select name="Day">';
      for($I = 1; $I < 32; $I++)
      {
        if($I == $TimeParts['mday']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select>. ';
      
      // Month selection
      $Output .= '<select name="Month">';
      foreach($Months as $Index => $Month)
      { 
        if($Index == $TimeParts['mon']) $Selected = ' selected="1"'; else $Selected = ''; 
        if($Index > 0) $Output .= '<option value="'.$Index.'"'.$Selected.'>'.$Month.'</option>';
      }
      $Output .= '</select>. ';
      
      // Day selection
      $Output .= '<select name="Year">';
      for($I = 2000; $I < 2010; $I++)
      { 
        if($I == $TimeParts['year']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select> &nbsp;&nbsp; ';
      
      
      // Hour selection
      $Output .= '<select name="Hour">';
      for($I = 0; $I < 24; $I++)
      { 
        if($I == $TimeParts['hours']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select> : ';

      // Minute selection
      $Output .= '<select name="Minute">';
      for($I = 0; $I < 60; $I++) 
      {
        if($I == $TimeParts['minutes']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select> ';
      $Output .= '<input type="submit" value="Nastavit">';     
      $Output .= '</form>';

      $Output .= ' <form style="display: inline;" action="?Operation=SetTimeNow&Time='.$Time.'" method="post">';
      $Output .= '<input type="submit" value="Aktuln as">';     
      $Output .= '</form>';
      
      return($Output);
}

$Months = array('', 'Leden', 'nor', 'Bezen', 'Duben', 'Kvten', 'erven', 'ervenec', 'Srpen', 'Z', 
  'jen', 'Listopad', 'Prosinec'); 

$GrafTimeRanges = array(
  'hour' => array(
    'caption' => 'Hodina', 
    'period' => 3600,
  ),
  'day' => array(
    'caption' => 'Den',
    'period' => 3600*24,
  ),
  'week' => array(
    'caption' => 'Tden',
    'period' => 3600*24*7,
  ),
  'month' => array(
    'caption' => 'Msc',
    'period' => 3600*24*30,
  ),
  'year' => array(
    'caption' => 'Rok',
    'period' => 3600*24*365,
  ),
  'years' => array(
    'caption' => 'Desetilet',
    'period' => 3600*24*365*10,
  ),
); 

session_start();

$Variables = array(
  'TimeStart' => time() - 3600*24,
  'TimeEnd' => time(),
  'Measure' => 1,
  'Period' => 'day',
  'TimeSpecify' => 0,
);

foreach($Variables as $Index => $Variable)
{
  if(!array_key_exists($Index, $_SESSION)) $_SESSION[$Index] = $Variable;
  if(array_key_exists($Index, $_GET)) $_SESSION[$Index] = $_GET[$Index];
  if(array_key_exists($Index, $_POST)) $_SESSION[$Index] = $_POST[$Index];
  //$$Index = $_SESSION[$Index];
} 

if($_SESSION['TimeSpecify'] == 0) 
{
  $_SESSION['TimeEnd'] = time() - 60;
  $_SESSION['TimeStart'] = $_SESSION['TimeEnd'] - $GrafTimeRanges[$_SESSION['Period']]['period'];
}

echo('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html><head>
  <meta http-equiv="Content-Language" content="cs">
  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-2">
  <title>Statistika</title>
  <LINK REL="StyleSheet" HREF="style.css" TYPE="text/css" MEDIA="all">
  </head><body style="font-family: sans-serif;">');
  echo('<div class="Title">Statistiky</div>');

if(!array_key_exists('Operation', $_GET)) $_GET['Operation'] = ''; 
switch($_GET['Operation'])
{
  case 'SetTime':
    if(array_key_exists('Time', $_GET) and array_key_exists('Month', $_POST) and array_key_exists('Day', $_POST) and
      array_key_exists('Year', $_POST) and array_key_exists('Hour', $_POST) and array_key_exists('Minute', $_POST))  
      {
        if(($_GET['Time'] == 'TimeStart') or ($_GET['Time'] == 'TimeEnd'))
        {
          $_SESSION[$_GET['Time']] = mktime($_POST['Hour'], $_POST['Minute'], 0, $_POST['Month'], 
            $_POST['Day'], $_POST['Year']);
          $$_GET['Time'] = $_SESSION[$_GET['Time']];
        }
      }
    break; 
  case 'SetTimeNow':
    if(array_key_exists('Time', $_GET)) 
    {
      if(($_GET['Time'] == 'TimeStart') or ($_GET['Time'] == 'TimeEnd'))
      {
        $_SESSION[$_GET['Time']] = time();
        $$_GET['Time'] = $_SESSION[$_GET['Time']];
      }
    }
    break; 
  
}
    echo('<strong>Men veliiny:</strong><br>');
    DB_Select('stat_measure', '*');
    while($Row = DB_Row())
      echo('<a href="?Measure='.$Row['id'].'">'.$Row['description'].'</a> ');
    echo('<br><br>');
    echo('<strong>asov sek:</strong><br>');
    // Show graf time range menu
    if($_SESSION['TimeSpecify'] == 0)
    {
      echo('Dlka seku: ');
      foreach($GrafTimeRanges as $Index => $Item)
        echo('<a href="?Period='.$Index.'">'.$Item['caption'].'</a>&nbsp;'); 
      echo('<br>');
      echo('<a href="?TimeSpecify=1">Pesnj nastaven...</a><br>');  
    } else {
      echo('<table cellspacing="0" cellpadding="2" border="0">');
      echo('<tr><td>Potek:</td><td>'.EditTime('TimeStart').'</td></tr>');
      echo('<tr><td>Konec:</td><td>'.EditTime('TimeEnd').'</td></tr>');
      echo('</table>');
      echo('<a href="?TimeSpecify=0">Jednoduch nastaven...</a><br>');  
    }
echo('<br>');
echo('<strong>Graf:</strong><br>');
echo('<img alt="Graf" src="graph.php?Measure='.$_SESSION['Measure'].'&amp;From='.$_SESSION['TimeStart'].'&amp;To='.$_SESSION['TimeEnd'].'&Width=750&Height=200" width="750" height="214"><br>');
//print_r(GetValues($Measure, $TimeStart, $TimeEnd));
 
echo('<br>');

echo('<table border="1" cellspacing="0" cellpadding="2" style="font-size: small;">');
echo('<tr><th>Men veliina</th><th>Posledn hodnota</th></tr>');
DB_Select('stat_measure', '*');
while($Measure = DB_Row())
{
  DB_Save();
  DB_Select('stat_data', 'avg', 'measure='.$Measure['id'].' ORDER BY time DESC LIMIT 1');
  $Row = DB_Row();
  echo('<tr><td>'.$Measure['description'].'</td><td align="right">'.($Row['avg'] / $Measure['divider']).' '.$Measure['unit'].'</td></tr>');  
  DB_Load();
}
echo('</table>');
echo('<br><a href="development/">Sekce vvoje systmu</a>');
//echo(time());
//print_r(gd_info());
echo('</body></html>');
//print_r($_SESSION);


?>

==> statistic-2.2.zip: index.php <==
<?
include('stat_functions.php');
include('db.php');
DB_Init('localhost', 'root', '', 'statistic');
DB_Query('SET CHARACTER SET latin2');

$Debug = 1;

function EditTime($Time)
{
      global $Months;
      
      $Output = '<form style="display: inline;" action="?Operation=SetTime&Time='.$Time.'" method="post">';
      
      $TimeParts = getdate($_SESSION[$Time]);
      //print_r($TimeParts); 
          
      // Day selection
      $Output .= '<select name="Day">';
      for($I = 1; $I < 32; $I++)
      {
        if($I == $TimeParts['mday']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select>. ';
      
      // Month selection
      $Output .= '<select name="Month">';
      foreach($Months as $Index => $Month)
      { 
        if($Index == $TimeParts['mon']) $Selected = ' selected="1"'; else $Selected = ''; 
        if($Index > 0) $Output .= '<option value="'.$Index.'"'.$Selected.'>'.$Month.'</option>';
      }
      $Output .= '</select>. ';
      
      // Day selection
      $Output .= '<select name="Year">';
      for($I = 2000; $I < 2010; $I++)
      { 
        if($I == $TimeParts['year']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select> &nbsp;&nbsp; ';
      
      
      // Hour selection
      $Output .= '<select name="Hour">';
      for($I = 0; $I < 24; $I++)
      { 
        if($I == $TimeParts['hours']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select> : ';

      // Minute selection
      $Output .= '<select name="Minute">';
      for($I = 0; $I < 60; $I++) 
      {
        if($I == $TimeParts['minutes']) $Selected = ' selected="1"'; else $Selected = ''; 
        $Output .= '<option value="'.$I.'"'.$Selected.'>'.$I.'</option>';
      }
      $Output .= '</select> ';
      $Output .= '<input type="submit" value="Nastavit">';     
      $Output .= '</form>';

      $Output .= ' <form style="display: inline;" action="?Operation=SetTimeNow&Time='.$Time.'" method="post">';
      $Output .= '<input type="submit" value="Aktuln as">';     
      $Output .= '</form>';
      
      return($Output);
}

$Months = array('', 'Leden', 'nor', 'Bezen', 'Duben', 'Kvten', 'erven', 'ervenec', 'Srpen', 'Z', 
  'jen', 'Listopad', 'Prosinec'); 

$GrafTimeRanges = array(
  'hour' => array(
    'caption' => 'Hodina', 
    'period' => 3600,
  ),
  'day' => array(
    'caption' => 'Den',
    'period' => 3600*24,
  ),
  'week' => array(
    'caption' => 'Tden',
    'period' => 3600*24*7,
  ),
  'month' => array(
    'caption' => 'Msc',
    'period' => 3600*24*30,
  ),
  'year' => array(
    'caption' => 'Rok',
    'period' => 3600*24*365,
  ),
  'years' => array(
    'caption' => 'Desetilet',
    'period' => 3600*24*365*10,
  ),
); 

session_start();

$Variables = array(
  'TimeStart' => time() - 3600*24,
  'TimeEnd' => time(),
  'Measure' => 1,
  'Period' => 'day',
  'TimeSpecify' => 0,
);

foreach($Variables as $Index => $Variable)
{
  if(!array_key_exists($Index, $_SESSION)) $_SESSION[$Index] = $Variable;
  if(array_key_exists($Index, $_GET)) $_SESSION[$Index] = $_GET[$Index];
  if(array_key_exists($Index, $_POST)) $_SESSION[$Index] = $_POST[$Index];
  //$$Index = $_SESSION[$Index];
} 

if($_SESSION['TimeSpecify'] == 0) 
{
  $_SESSION['TimeEnd'] = time() - 60;
  $_SESSION['TimeStart'] = $_SESSION['TimeEnd'] - $GrafTimeRanges[$_SESSION['Period']]['period'];
}

echo('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html><head>
  <meta http-equiv="Content-Language" content="cs">
  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-2">
  <title>Statistika</title>
  <LINK REL="StyleSheet" HREF="style.css" TYPE="text/css" MEDIA="all">
  </head><body style="font-family: sans-serif;">');
  echo('<div class="Title">Statistiky</div>');

if(!array_key_exists('Operation', $_GET)) $_GET['Operation'] = ''; 
switch($_GET['Operation'])
{
  case 'SetTime':
    if(array_key_exists('Time', $_GET) and array_key_exists('Month', $_POST) and array_key_exists('Day', $_POST) and
      array_key_exists('Year', $_POST) and array_key_exists('Hour', $_POST) and array_key_exists('Minute', $_POST))  
      {
        if(($_GET['Time'] == 'TimeStart') or ($_GET['Time'] == 'TimeEnd'))
        {
          $_SESSION[$_GET['Time']] = mktime($_POST['Hour'], $_POST['Minute'], 0, $_POST['Month'], 
            $_POST['Day'], $_POST['Year']);
          $$_GET['Time'] = $_SESSION[$_GET['Time']];
        }
      }
    break; 
  case 'SetTimeNow':
    if(array_key_exists('Time', $_GET)) 
    {
      if(($_GET['Time'] == 'TimeStart') or ($_GET['Time'] == 'TimeEnd'))
      {
        $_SESSION[$_GET['Time']] = time();
        $$_GET['Time'] = $_SESSION[$_GET['Time']];
      }
    }
    break; 
  
}
    echo('<strong>Men veliiny:</strong><br>');
    DB_Select('stat_measure', '*');
    while($Row = DB_Row())
      echo('<a href="?Measure='.$Row['id'].'">'.$Row['description'].'</a> ');
    echo('<br><br>');
    echo('<strong>asov sek:</strong><br>');
    // Show graf time range menu
    if($_SESSION['TimeSpecify'] == 0)
    {
      echo('Dlka seku: ');
      foreach($GrafTimeRanges as $Index => $Item)
        echo('<a href="?Period='.$Index.'">'.$Item['caption'].'</a>&nbsp;'); 
      echo('<br>');
      echo('<a href="?TimeSpecify=1">Pesnj nastaven...</a><br>');  
    } else {
      echo('<table cellspacing="0" cellpadding="2" border="0">');
      echo('<tr><td>Potek:</td><td>'.EditTime('TimeStart').'</td></tr>');
      echo('<tr><td>Konec:</td><td>'.EditTime('TimeEnd').'</td></tr>');
      echo('</table>');
      echo('<a href="?TimeSpecify=0">Jednoduch nastaven...</a><br>');  
    }
echo('<br>');
echo('<strong>Graf:</strong><br>');
echo('<img alt="Graf" src="graph.php?Measure='.$_SESSION['Measure'].'&amp;From='.$_SESSION['TimeStart'].'&amp;To='.$_SESSION['TimeEnd'].'&Width=750&Height=200" width="750" height="214"><br>');
//print_r(GetValues($Measure, $TimeStart, $TimeEnd));
 
echo('<br>');

echo('<table border="1" cellspacing="0" cellpadding="2" style="font-size: small;">');
echo('<tr><th>Men veliina</th><th>as poslednho men</th><th>Posledn hodnota</th><th>Interpolace</th><th>Poznmky</th></tr>');
DB_Select('stat_measure', '*', '1 ORDER BY description');
while($Measure = DB_Row())
{
  DB_Save();
  DB_Select('stat_data', 'time, avg', 'measure='.$Measure['id'].' ORDER BY time DESC LIMIT 1');
  if(DB_NumRows() > 0)
  {
    $Row = DB_Row();
    if($Measure['continuity'] == 1) $Interpolate = 'Ano'; else $Interpolate = 'Ne';
    if($Measure['info'] == '') $Measure['info'] = '&nbsp;';
    echo('<tr><td>'.$Measure['description'].'</td><td align="center">'.date('j.n.Y G:i:s', MysqlDateTimeToTime($Row['time'])).'</td><td align="center">'.($Row['avg'] / $Measure['divider']).' '.$Measure['unit'].'</td><td align="center">'.$Interpolate.'</td><td>'.$Measure['info'].'</td></tr>');
  }  
  DB_Load();
}
echo('</table>');
echo('<br><a href="development/">Sekce vvoje systmu</a>');
//echo(time());
//print_r(gd_info());
echo('<br><div style="font-size: small;">Kontakt: robie@centrum.cz</div>');
echo('</body></html>');
//print_r($_SESSION);



?>
